A Pelican Blog - misc

# FILENAME_METADATA example

Some cool stuff!

# Other articles

1. # Second article

   This is some article, in english

   read more

2. # Unbelievable !

   Or completely awesome. Depends the needs.

   a root-relative link to markdown-article a file-relative link to markdown-article

   ## Testing sourcecode directive

       1
       formatter = self.options and VARIANTS[self.options.keys()[0]]

   ## Testing another case

   This will now have a line number in 'custom' since it's the default in pelican.conf, it will …

   read more

3. # The baz tag

   This article overrides the listening of the articles under the baz tag.

   read more

## social

- atom feed